@@ -144,6 +144,9 @@ class TracedData(pydantic.BaseModel):
     request_reasoning_summary: Optional[str] = pydantic.Field(default=None)
     request_reasoning_effort: Optional[str] = pydantic.Field(default=None)
 
+    request_service_tier: Optional[str] = pydantic.Field(default=None)
+    response_service_tier: Optional[str] = pydantic.Field(default=None)
+
 
 responses: dict[str, TracedData] = {}
 
@@ -232,6 +235,17 @@ def set_data_attributes(traced_response: TracedData, span: Span):
         traced_response.request_reasoning_effort or (),
     )
 
+    _set_span_attribute(
+        span,
+        "openai.request.service_tier",
+        traced_response.request_service_tier,
+    )
+    _set_span_attribute(
+        span,
+        "openai.response.service_tier",
+        traced_response.response_service_tier,
+    )
+
     if should_send_prompts():
         prompt_index = 0
         if traced_response.tools:
@@ -496,6 +510,10 @@ def responses_get_or_create_wrapper(tracer: Tracer, wrapped, instance, args, kwa
                 request_reasoning_effort=kwargs.get("reasoning", {}).get(
                     "effort", existing_data.get("request_reasoning_effort")
                 ),
+                request_service_tier=kwargs.get(
+                    "service_tier", existing_data.get("request_service_tier")
+                ),
+                # response_service_tier=existing_data.get("response_service_tier"),
             )
         except Exception:
             traced_data = None
@@ -548,6 +566,13 @@ def responses_get_or_create_wrapper(tracer: Tracer, wrapped, instance, args, kwa
             request_reasoning_effort=existing_data.get(
                 "request_reasoning_effort", kwargs.get("reasoning", {}).get("effort")
             ),
+            request_service_tier=existing_data.get(
+                "request_service_tier", kwargs.get("service_tier")
+            ),
+            response_service_tier=existing_data.get(
+                "response_service_tier",
+                parsed_response.service_tier,
+            ),
         )
         responses[parsed_response.id] = traced_data
     except Exception:
@@ -607,6 +632,10 @@ async def async_responses_get_or_create_wrapper(
                 request_reasoning_effort=kwargs.get("reasoning", {}).get(
                     "effort", existing_data.get("request_reasoning_effort")
                 ),
+                request_service_tier=kwargs.get(
+                    "service_tier", existing_data.get("request_service_tier")
+                ),
+                # response_service_tier=existing_data.get("response_service_tier"),
             )
         except Exception:
             traced_data = None
@@ -659,6 +688,13 @@ async def async_responses_get_or_create_wrapper(
             request_reasoning_effort=existing_data.get(
                 "request_reasoning_effort", kwargs.get("reasoning", {}).get("effort")
             ),
+            request_service_tier=existing_data.get(
+                "request_service_tier", kwargs.get("service_tier")
+            ),
+            response_service_tier=existing_data.get(
+                "response_service_tier",
+                parsed_response.service_tier,
+            ),
         )
         responses[parsed_response.id] = traced_data
     except Exception:
