@@ -604,9 +604,11 @@ class Laminar:
                 this mechanism if it was previously set manually.
         """
         if not cls.is_initialized():
-            yield from use_span(
+            with use_span(
                 span, end_on_exit, record_exception, set_status_on_exception
-            )
+            ) as s:
+                yield s
+            return
 
         wrapper = TracerWrapper()
 
@@ -890,7 +892,9 @@ class Laminar:
 
     @classmethod
     def force_flush(cls):
-        """Force flush the internal tracer.
+        """Force flush the internal tracer. WARNING: Any active spans are
+        removed from context; that is, spans started afterwards will start
+        a new trace.
 
         Actually shuts down the span processor and re-initializes it as long
         as it is a LaminarSpanProcessor. This is not recommended in production
